@@ -1,4 +1,4 @@
-from .experiment import Experiment, Evaluation
+from .experiment import Experiment, Evaluation, Filter, FilterScope
 from .metric import Metric
 from .check import Check, SrmCheck
 from .parser import Parser, EpGoal
